@@ -39,7 +39,8 @@ hashtag_changesets = {}
 countries_changesets = {}
 
 # read the GeoJSON file
-countries_df = gpd.read_file("data/countries_un.geojson")
+working_dir = os.path.realpath(os.getcwd())
+countries_df = gpd.read_file(os.path.join(working_dir, "data/countries_un.geojson"))
 
 
 def collect_changefile_stats(user, uname, changeset, version, tags, osm_type):
